AutomaticFilters: Simple filtering
==================================

The AutomaticFilters extension provides a simpler approach to building filters 
using Ingredient.build_filter.


.. module:: recipe

.. autoclass:: AutomaticFilters
    :members: apply_automatic_filters,automatic_filters,include_automatic_filter_keys,exclude_automatic_filter_keys
    :noindex:
    
The AutomaticFilters extension.

